Instrument

Trait Instrument 

pub trait Instrument {
    // Required methods
    fn on_enter(&mut self);
    fn on_exit(&mut self);
}
Signal when a span is entered or exited.

Some implementations for commonly used types are provided in the instruments module. You may also implement this trait yourself.

Required Methods

fn on_enter(&mut self)

This method is called when the span is entered.

fn on_exit(&mut self)

This method is called when the span is exited.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'a, P: OutputPin> Instrument for GpioRef<'a, P>

Source

impl<'a, P: OutputPin> Instrument for LegacyGpioRef<'a, P>

Available on crate feature embedded-hal_0_2 only.
Source

impl<P: OutputPin> Instrument for Gpio<P>

Source

impl<P: OutputPin> Instrument for LegacyGpio<P>

Available on crate feature embedded-hal_0_2 only.